summaryrefslogtreecommitdiffstats
path: root/noatun/library/playlistsaver.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/playlistsaver.cpp')
-rw-r--r--noatun/library/playlistsaver.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/noatun/library/playlistsaver.cpp b/noatun/library/playlistsaver.cpp
index 15fcad58..f5bd09bd 100644
--- a/noatun/library/playlistsaver.cpp
+++ b/noatun/library/playlistsaver.cpp
@@ -291,7 +291,7 @@ public:
if(a.qName(i).lower()=="href")
{
TQString filename=a.value(i);
- if (filename.tqfind(TQRegExp("^[a-zA-Z0-9]+:/"))==0)
+ if (filename.find(TQRegExp("^[a-zA-Z0-9]+:/"))==0)
{
KURL url(filename);
KMimeType::Ptr mimetype = KMimeType::findByURL(url);
@@ -316,7 +316,7 @@ public:
{
KURL u1;
// we have to deal with a relative path
- if (filename.tqfind('/'))
+ if (filename.find('/'))
{
u1.setPath(mAbsPath); //FIXME: how to get the path in this place?
u1.setFileName(filename);
@@ -541,7 +541,7 @@ bool PlaylistSaver::loadM3U(const KURL &file, int /*opt*/)
if (filename.isEmpty())
continue;
- if (filename.tqfind(TQRegExp("^[a-zA-Z0-9]+:/"))==0)
+ if (filename.find(TQRegExp("^[a-zA-Z0-9]+:/"))==0)
{
//kdDebug(66666) << k_funcinfo << "url filename = " << filename << endl;
@@ -569,7 +569,7 @@ bool PlaylistSaver::loadM3U(const KURL &file, int /*opt*/)
{
KURL u1;
// we have to deal with a relative path
- if (filename.tqfind('/'))
+ if (filename.find('/'))
{
u1.setPath(file.path(0));
u1.setFileName(filename);
@@ -587,7 +587,7 @@ bool PlaylistSaver::loadM3U(const KURL &file, int /*opt*/)
{
extinf.remove(0,8); // remove "#EXTINF:"
//kdDebug(66666) << "EXTM3U extinf = '" << extinf << "'" << endl;
- int timeTitleSep = extinf.tqfind(',', 0);
+ int timeTitleSep = extinf.find(',', 0);
int length = (extinf.left(timeTitleSep)).toInt();
if (length>0)
@@ -596,7 +596,7 @@ bool PlaylistSaver::loadM3U(const KURL &file, int /*opt*/)
TQString displayTitle=extinf.mid(timeTitleSep+1);
if (!displayTitle.isEmpty())
{
- int artistTitleSep = displayTitle.tqfind(" - ",0);
+ int artistTitleSep = displayTitle.find(" - ",0);
if (artistTitleSep == -1) // no "artist - title" like format, just set it as title
{
prop["title"] = displayTitle;
@@ -718,7 +718,7 @@ bool PlaylistSaver::loadPLS(const KURL &file, int /*opt*/)
// some stupid Windows lusers like to be case insensitive
TQStringList groups = list.groupList().grep(TQRegExp("^playlist$", false));
/*
- if (!groups.count()) // didn't tqfind "[playlist]", it's not a .pls file
+ if (!groups.count()) // didn't find "[playlist]", it's not a .pls file
return false;
*/